summaryrefslogtreecommitdiffstats
path: root/quanta/src/quantaview.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/src/quantaview.h')
-rw-r--r--quanta/src/quantaview.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/quanta/src/quantaview.h b/quanta/src/quantaview.h
index 24ecd776..f8033133 100644
--- a/quanta/src/quantaview.h
+++ b/quanta/src/quantaview.h
@@ -19,11 +19,11 @@
#define QUANTAVIEW_H
// include files for Qt
-#include <qguardedptr.h>
-#include <qwidget.h>
-#include <qptrlist.h>
-#include <qvaluelist.h>
-#include <qtimer.h>
+#include <tqguardedptr.h>
+#include <tqwidget.h>
+#include <tqptrlist.h>
+#include <tqvaluelist.h>
+#include <tqtimer.h>
//kde includes
#include <kmdichildview.h>
@@ -53,7 +53,7 @@ class QSplitter;
class Node;
/** The QuantaView class provides the view widget for the QuantaApp
* instance. The View instance inherits QWidget as a base class and
* represents the view object of a KTMainWindow. As QuantaView is part
* of the docuement-view model, it needs a reference to the document
* object connected with it by the QuantaApp class to manipulate and
@@ -67,7 +67,7 @@ class QuantaView : public KMdiChildView
public:
- QuantaView(QWidget *parent = 0, const char *name=0, const QString &caption = QString::null);
+ QuantaView(TQWidget *parent = 0, const char *name=0, const TQString &caption = TQString::null);
~QuantaView();
/** returns true if the view can be removed, false otherwise */
@@ -77,7 +77,7 @@ public:
void addDocument(Document *document);
/** Adds a custom widget to the view. */
- void addCustomWidget(QWidget *widget, const QString &label);
+ void addCustomWidget(TQWidget *widget, const TQString &label);
/** returns the Document object associated with this view. Returns 0L if the view holds
a non-Document object */
@@ -86,7 +86,7 @@ public:
/**Adds a QuantaPlugin object to the view.*/
void addPlugin(QuantaPlugin *plugin);
- QWidget* documentArea() {return m_documentArea;}
+ TQWidget* documentArea() {return m_documentArea;}
bool saveDocument(const KURL&);
/** Saves the document if it's modified. Ask the user if their
@@ -114,7 +114,7 @@ public:
/** Called when this view lost the active status */
void deactivated();
- void resizeEvent(QResizeEvent* e);
+ void resizeEvent(TQResizeEvent* e);
/** Resize the current view */
void resize(int width, int height);
/** Redraws the view, resizes the components to their correct size */
@@ -124,17 +124,17 @@ public:
void updateTab();
/** Returns the tab name associated with this view */
- QString tabName();
+ TQString tabName();
void insertTag( const char *tag);
/** Insert a new tag by bringing up the TagDialog. */
- void insertNewTag(const QString &tag, const QString &attr = QString::null, bool insertInLine = true);
+ void insertNewTag(const TQString &tag, const TQString &attr = TQString::null, bool insertInLine = true);
/**
* This function take the output of the TagAction, parse it into Nodes and insert it
* in the Node tree. Then kafka will take care of updating itself from the Node Tree.
*/
- void insertOutputInTheNodeTree(const QString &str1, const QString &str2 = QString::null, Node *node = 0L);
+ void insertOutputInTheNodeTree(const TQString &str1, const TQString &str2 = TQString::null, Node *node = 0L);
enum ViewFocus {
SourceFocus = 0,
@@ -180,7 +180,7 @@ public slots:
private slots:
void slotSavingCompleted();
- void slotSavingFailed(const QString& error);
+ void slotSavingFailed(const TQString& error);
/**
* Called to update VPL.
@@ -194,40 +194,40 @@ private slots:
signals:
/** emitted when a file from the template view is dropped on the view */
- void dragInsert(QDropEvent *);
+ void dragInsert(TQDropEvent *);
/** asks for hiding the preview widget */
void hidePreview();
void showProblemsView();
void cursorPositionChanged();
- void title(const QString &);
+ void title(const TQString &);
/** emitted if this view contained an editor and it is closed */
void documentClosed(const KURL&);
- void eventHappened(const QString&, const QString&, const QString& );
+ void eventHappened(const TQString&, const TQString&, const TQString& );
private:
/** Kafka stuff */
- QValueList<int> m_splitterSizes;
+ TQValueList<int> m_splitterSizes;
int m_curCol, m_curLine, m_curOffset;
DOM::Node curNode;
bool m_kafkaReloadingEnabled, m_quantaReloadingEnabled;
- QTimer m_sourceUpdateTimer, m_VPLUpdateTimer;
+ TQTimer m_sourceUpdateTimer, m_VPLUpdateTimer;
- QWidget *m_documentArea;///< the area of the view which can be used to show the source/VPL
+ TQWidget *m_documentArea;///< the area of the view which can be used to show the source/VPL
Document *m_document;
QuantaPlugin *m_plugin;
- QWidget *m_customWidget; ///<view holds a custom widget, eg. a documentation
- QGuardedPtr<KafkaDocument> m_kafkaDocument;
- QSplitter *m_splitter;
- QGridLayout *m_viewLayout;
+ TQWidget *m_customWidget; ///<view holds a custom widget, eg. a documentation
+ TQGuardedPtr<KafkaDocument> m_kafkaDocument;
+ TQSplitter *m_splitter;
+ TQGridLayout *m_viewLayout;
int m_currentViewsLayout; ///< holds the current layout, which can be SourceOnly, VPLOnly or SourceAndVPL
int m_currentFocus;
bool m_saveResult;
bool m_eventLoopStarted;
protected:
- virtual void dropEvent(QDropEvent *e);
- virtual void dragEnterEvent(QDragEnterEvent *e);
+ virtual void dropEvent(TQDropEvent *e);
+ virtual void dragEnterEvent(TQDragEnterEvent *e);
};
#endif // QUANTAVIEW_H
@@ -53,7 +53,7 @@ class QSplitter;
class Node;
/** The QuantaView class provides the view widget for the QuantaApp
- * instance. The View instance inherits QWidget as a base class and
+ * instance. The View instance inherits TQWidget as a base class and
* represents the view object of a KTMainWindow. As QuantaView is part
* of the docuement-view model, it needs a reference to the document